import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.StringReader;
import java.nio.file.Paths;
import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.TokenStream;
//import org.apache.lucene.analysis.cn.smart.SmartChineseAnalyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
//import org.apache.lucene.document.IntField;
import org.apache.lucene.document.StringField;
import org.apache.lucene.document.TextField;
import org.apache.lucene.index.DirectoryReader;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.IndexWriterConfig;
import org.apache.lucene.queryparser.classic.ParseException;
import org.apache.lucene.queryparser.classic.QueryParser;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.ScoreDoc;
import org.apache.lucene.search.TopDocs;
import org.apache.lucene.search.highlight.Fragmenter;
import org.apache.lucene.search.highlight.Highlighter;
import org.apache.lucene.search.highlight.InvalidTokenOffsetsException;
import org.apache.lucene.search.highlight.QueryScorer;
import org.apache.lucene.search.highlight.SimpleHTMLFormatter;
import org.apache.lucene.search.highlight.SimpleSpanFragmenter;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.FSDirectory;


import org.json.simple.JSONArray;
import org.json.simple.JSONObject;
import org.json.simple.parser.*;

public class Searcher {
	private IndexSearcher searcher;
    private IndexReader index;
    
	 public Searcher(String indexDir) throws IOException {
	        Directory indexFile = FSDirectory.open(Paths.get(indexDir));
	        this.index = DirectoryReader.open(indexFile);
	        this.searcher=new IndexSearcher(this.index);
	 }
	 public void search(String querystr) throws ParseException, IOException, InvalidTokenOffsetsException {
		 Analyzer analyzer=new StandardAnalyzer();
		 //QueryParser parser=new QueryParser("s1",analyzer);
		 QueryParser parser=new QueryParser("s1",analyzer);
	     Query query=parser.parse(querystr);
	     
	     long start=System.currentTimeMillis();
	     TopDocs hits=searcher.search(query, 4);
	     long end=System.currentTimeMillis();
	     System.out.println("searching "+querystr+", consuming "+(end-start)+" millisecond. "+"finds "+hits.totalHits+"records");
	     
	     QueryScorer scorer= new QueryScorer(query);
	     Fragmenter fragmenter=new SimpleSpanFragmenter(scorer);
	     SimpleHTMLFormatter simpleHTMLFormatter=new SimpleHTMLFormatter("<b>","</b>");
	     Highlighter highlighter=new Highlighter(simpleHTMLFormatter, scorer);
	     highlighter.setTextFragmenter(fragmenter);
	     
	  
	     for(ScoreDoc scoreDoc:hits.scoreDocs){
	            Document doc=searcher.doc(scoreDoc.doc);
	            //System.out.println(doc);
	            String id=doc.get("id");
	            //System.out.print(doc.get("id")+"\t");
	            //System.out.print(doc.get("s1")+"\t"+doc.get("s2")+"\t");
	            String s1 = doc.get("s1");
	            String s2 = doc.get("s2");
	            
	            
	            //TokenStream tokenStream1=analyzer.tokenStream("s1", new StringReader(s1));
	            TokenStream tokenStream2=analyzer.tokenStream("s1", new StringReader(s2));
	            
	            //System.out.println(highlighter.getBestFragment(tokenStream1, s1));
	            System.out.println(highlighter.getBestFragment(tokenStream2, s2));
	      }
	 }
	 public static void main(String[] args) throws InvalidTokenOffsetsException, IOException, ParseException {
		 String querystr = "man playing is";
		 Searcher searcher = new Searcher("your index path");
		 searcher.search(querystr);
	 }
	 
}
